From 6ff3683c9c094019d15b815ccdba8f7fb03c9109 Mon Sep 17 00:00:00 2001
From: Johannes Hoermann <j.hoermann@adito.de>
Date: Mon, 25 Mar 2019 15:27:29 +0100
Subject: [PATCH] rename functions: relation to contact

---
 process/Contact_lib/process.js       | 6 +++---
 process/PostalAddress_lib/process.js | 4 ++--
 2 files changed, 5 insertions(+), 5 deletions(-)

diff --git a/process/PostalAddress_lib/process.js b/process/PostalAddress_lib/process.js
index 7c96f2e623..f3f2b67f1b 100644
--- a/process/PostalAddress_lib/process.js
+++ b/process/PostalAddress_lib/process.js
@@ -75,7 +75,7 @@ AddressUtils.getAddress = function(pContactId) {
         address[4] = dummyAddress[3];
         
     }
-    var type = ContactUtils.getContactTypeByContact(pContactId);
+    var type = ContactUtils.getContactTypeByContactId(pContactId);
     
     return AddressUtils.formatAddress(type, address[1], address[2], address[3], address[4], address[5], address[6], address[7], address[8]);
 }
@@ -103,7 +103,7 @@ AddressUtils.getAddressById = function(pAddressId) {
         address[4] = dummyAddress[4];
         
     }
-    var type = ContactUtils.getContactTypeByContact(address[0]);   
+    var type = ContactUtils.getContactTypeByContactId(address[0]);   
 
     var names = db.array(db.ROW, SqlCondition.begin()
                                              .andPrepare("CONTACT.CONTACTID", address[0])
diff --git a/process/Contact_lib/process.js b/process/Contact_lib/process.js
index c3b389da09..4dc852d62e 100644
--- a/process/Contact_lib/process.js
+++ b/process/Contact_lib/process.js
@@ -63,7 +63,7 @@ ContactUtils.getContactType = function(pContactId, pPersId, pOrgId)
 {
     if (vars.get("$sys.recordstate") == neon.OPERATINGSTATE_NEW || vars.get("$sys.recordstate") == neon.OPERATINGSTATE_EDIT)
     {
-        return ContactUtils.getContactTypeByContact(pContactId);
+        return ContactUtils.getContactTypeByContactId(pContactId);
     }
     else
     {
@@ -81,7 +81,7 @@ ContactUtils.getContactType = function(pContactId, pPersId, pOrgId)
  *                  2 if privat person <br>
  *                  3 if person of an organisation <br>
  */
-ContactUtils.getContactTypeByContact = function(pContactId)
+ContactUtils.getContactTypeByContactId = function(pContactId)
 {
     var relationData = ContactUtils.getPersOrgIds(pContactId);
     if (relationData[0]) 
@@ -102,7 +102,7 @@ ContactUtils.getContactTypeByContact = function(pContactId)
  * !!It does not check if the person / org ids really exist!! <br>
  * !!And it does not check if really any contact with this person / org ids exist!! <br>
  *  <br>
  * This function is more performant than getContactTypeByContact, <br>
  * because it doesn't load something from the db. <br>
  *  <br>
  * It is meant to be used by entitys, where you can load person and org with the DataRecord. <br>
@@ -102,7 +102,7 @@ ContactUtils.getContactTypeByContact = function(pContactId)
  * !!And it does not check if really any contact with this person / org ids exist!! <br>
  *  <br>
- * This function is more performant than getContactTypeByContact, <br>
+ * This function is more performant than getContactTypeByContactId, <br>
  * because it doesn't load something from the db. <br>
  *  <br>
-- 
GitLab